import { ReactPropsWithoutRef, IComponent } from '@clutchd/component';
import { IWithColor } from '@clutchd/tailwind';

/**
 * Type to define `Content` component
 */
declare type IContent = typeof Content;
/**
 * Type to define `Content` props
 */
interface IContentProps extends ReactPropsWithoutRef<IComponent["main"]> {
    direction?: "col" | "row";
    padding?: boolean;
}
/**
 * `Content` - A `Container` designed to contain a page's primary content. Renders as a `main` element
 * @param props `IContentProps` used to render this `Content`
 * @returns `Content` component
 */
declare function Content({ children, className, direction, padding, ...props }: IContentProps): JSX.Element;

/**
 * Type to define `Footer` component
 */
declare type IFooter = typeof Footer;
/**
 * Type to define `Footer` props
 */
interface IFooterProps extends ReactPropsWithoutRef<IComponent["footer"]> {
    direction?: "col" | "row";
    padding?: boolean;
}
/**
 * `Footer` - A `Container` designed to contain a page's footer content. Renders as a `footer` element
 * @param props `IFooterProps` used to render this `Footer`
 * @returns `Footer` component
 */
declare function Footer({ children, className, direction, padding, ...props }: IFooterProps): JSX.Element;

/**
 * Type to define `Header` component
 */
declare type IHeader = typeof Header;
/**
 * Type to define `Header` props
 */
interface IHeaderProps extends ReactPropsWithoutRef<IComponent["header"]> {
    direction?: "col" | "row";
    padding?: boolean;
}
/**
 * `Header` - A `Container` designed to contain a page's header content. Renders as a `header` element
 * @param props `IHeaderProps` used to render this `Header`
 * @returns `Header` component
 */
declare function Header({ children, className, direction, padding, ...props }: IHeaderProps): JSX.Element;

/**
 * Type to define `Page` component
 */
declare type IPage = typeof Page;
/**
 * Type to define `Page` props
 */
interface IPageProps extends IWithColor, ReactPropsWithoutRef<IComponent["div"]> {
    direction?: "col" | "row";
    padding?: boolean;
}
/**
 * `Page` - A `Container` designed to contain an entire page. Renders as a `div` element that fills the screen
 * @param props `IPageProps` used to render this `Page`
 * @returns `Page` component
 */
declare function Page({ className, direction, theme, ...props }: IPageProps): JSX.Element;

export { Content, Footer, Header, IContent, IContentProps, IFooter, IFooterProps, IHeader, IHeaderProps, IPage, IPageProps, Page };
